==> 0.0.2.tar.gz: android/src/main/java/ai/think360/algo360pfm/WebActivity.kt <==
package ai.think360.algo360pfm

import `in`.thinkanalytics.algo360SDK.Helpers.HelperClass
import `in`.thinkanalytics.algo360SDK.Helpers.Urls
import ai.think360.algo360pfm.databinding.ActivityWebBinding
import ai.think360.algo360pfm.services.PermissionService
import android.content.Context
import android.os.Bundle
import android.util.Log
import android.view.View
import android.webkit.PermissionRequest
import android.webkit.WebSettings
import android.webkit.WebView
import androidx.appcompat.app.AlertDialog
import androidx.appcompat.app.AppCompatActivity
import org.json.JSONObject
import java.util.*


class WebActivity : AppCompatActivity() {
    lateinit var binding: ActivityWebBinding

    var permissionService: PermissionService = PermissionService(this)
    lateinit var webview: WebView
    private var myRequest: PermissionRequest? = null
    var env: String? = null
    var url: String? = null

    override fun onCreate(savedInstanceState: Bundle?) {
        super.onCreate(savedInstanceState)
        binding = ActivityWebBinding.inflate(layoutInflater)
        val view = binding.root
        setContentView(view)

        supportActionBar?.setDisplayHomeAsUpEnabled(true)
        supportActionBar?.title = "My Expenses"

        env = intent.getStringExtra("env")
        val url = if (env == "UAT") {
            "https://algo360uat.kotaksecurities.in"
        } else {
            "https://algo360prod.kotaksecurities.in"
        }

        val apiToken = intent.getStringExtra("api_token")
        val refId = intent.getStringExtra("ref_id")
        val accept = "image/webp,image/apng,image/svg+xml,image/*,*/*;q=0.8"
        val theme = HelperClass.getFromSettings(applicationContext, "THEME")

        var tokenHeader = mapOf("api_token" to apiToken, "Accept" to accept)

        val responseData = JSONObject()

        responseData.put("type", "RESPONSE_FROM_NATIVE")
        responseData.put("request", apiToken)

        val ps = PermissionService(this)
        ps.getAllPermission()

        try {
            try {
                val myWebView = binding.webview
                myWebView.webViewClient = WebViewClient()
                val webSettings = myWebView.settings
                webSettings.databaseEnabled = true
                webSettings.javaScriptEnabled = true
                webSettings.mediaPlaybackRequiresUserGesture = false
                WebView.setWebContentsDebuggingEnabled(true)
                webSettings.javaScriptCanOpenWindowsAutomatically = true
                webSettings.databaseEnabled = true
                webSettings.setGeolocationEnabled(true)
                webSettings.setGeolocationDatabasePath("/data/data/databases/")
                webSettings.loadsImagesAutomatically = true
                webSettings.cacheMode = WebSettings.LOAD_NO_CACHE
                webSettings.builtInZoomControls = false
                webSettings.domStorageEnabled = true
                webSettings.loadWithOverviewMode = true
                webSettings.useWideViewPort = true
                webSettings.setSupportZoom(true)
                webSettings.layoutAlgorithm = WebSettings.LayoutAlgorithm.SINGLE_COLUMN
                myWebView.scrollBarStyle = WebView.SCROLLBARS_OUTSIDE_OVERLAY
                myWebView.isScrollbarFadingEnabled = true
                myWebView.loadUrl("javascript:dataFromNative('$responseData')")
                val settings: WebSettings = myWebView.settings
                settings.databaseEnabled = true
                settings.domStorageEnabled = true
                val databasePath =
                    this.applicationContext.getDir("web_database", Context.MODE_PRIVATE).path
                settings.setDatabasePath(databasePath)
                myWebView.loadUrl(
                    "${url}/pfm-app?theme=${theme.lowercase()}&api_token=${apiToken}&ref_id=${refId}",
                    tokenHeader
                )

            } catch (y: Exception) {
                y.printStackTrace()
            }
        } catch (e: Exception) {
            e.printStackTrace()
        }
    }


    override fun onSupportNavigateUp(): Boolean {
        onBackPressed()
        return true
    }


    // Overriding WebViewClient functions
    inner class WebViewClient : android.webkit.WebViewClient() {

        // Load the URL
        @Deprecated("Deprecated in Java")
        override fun shouldOverrideUrlLoading(view: WebView, url: String): Boolean {
            view.loadUrl(url)
            return false
        }

        // ProgressBar will disappear once page is loaded
        override fun onPageFinished(view: WebView, url: String) {
            super.onPageFinished(view, url)
            binding.progressBarWebview.visibility = View.GONE
        }
    }

    @Deprecated("Deprecated in Java")
    override fun onBackPressed() {
        val dialogBuilder = AlertDialog.Builder(this)
            .setMessage("Are you sure you want to close?")
            .setPositiveButton(
                "Yes"
            ) { _, _ ->

                Log.d("DATA", "ON dashboard Page")
                finish()
                super.onBackPressed()
            }
            .setNegativeButton("No", null)

        val dialog: AlertDialog = dialogBuilder.create()
        dialog.show()
    }
}

==> 0.0.5.tar.gz: android/src/main/java/ai/think360/algo360pfm/WebActivity.kt <==
package ai.think360.algo360pfm

import `in`.thinkanalytics.algo360SDK.Helpers.HelperClass
import ai.think360.algo360pfm.databinding.ActivityWebBinding
import ai.think360.algo360pfm.services.PermissionService
import android.content.Context
import android.os.Bundle
import android.util.Log
import android.view.View
import android.webkit.PermissionRequest
import android.webkit.WebSettings
import android.webkit.WebView
import androidx.appcompat.app.AlertDialog
import androidx.appcompat.app.AppCompatActivity
import org.json.JSONObject
import java.util.*


class WebActivity : AppCompatActivity() {
    lateinit var binding: ActivityWebBinding

    lateinit var webview: WebView
    private var myRequest: PermissionRequest? = null
    var env: String? = null
    var url: String? = null
    var userId: String? = null
    var clientId: String? = null
    var clientSecret: String? = null

    override fun onCreate(savedInstanceState: Bundle?) {
        super.onCreate(savedInstanceState)
        binding = ActivityWebBinding.inflate(layoutInflater)
        val view = binding.root
        setContentView(view)

        supportActionBar?.setDisplayHomeAsUpEnabled(true)
        supportActionBar?.title = "My Expenses"

        env = intent.getStringExtra("env")
        userId = intent.getStringExtra("userId")
        clientId = intent.getStringExtra("clientId")
        clientSecret = intent.getStringExtra("clientSecret")
        val url = if (env == "UAT") {
            "https://algo360uat.kotaksecurities.in"
        } else {
            "https://algo360prod.kotaksecurities.in"
        }

        val apiToken = intent.getStringExtra("api_token")
        val refId = intent.getStringExtra("ref_id")
        val accept = "image/webp,image/apng,image/svg+xml,image/*,*/*;q=0.8"
        val theme = HelperClass.getFromSettings(applicationContext, "THEME")

        var tokenHeader = mapOf("api_token" to apiToken, "Accept" to accept)

        val responseData = JSONObject()

        responseData.put("type", "RESPONSE_FROM_NATIVE")
        responseData.put("request", apiToken)

        val ps = PermissionService(this,env!!,userId!!,clientId!!,clientSecret!!)
        ps.getAllPermission()

        try {
            try {
                val myWebView = binding.webview
                myWebView.webViewClient = WebViewClient()
                val webSettings = myWebView.settings
                webSettings.databaseEnabled = true
                webSettings.javaScriptEnabled = true
                webSettings.mediaPlaybackRequiresUserGesture = false
                WebView.setWebContentsDebuggingEnabled(true)
                webSettings.javaScriptCanOpenWindowsAutomatically = true
                webSettings.databaseEnabled = true
                webSettings.setGeolocationEnabled(true)
                webSettings.setGeolocationDatabasePath("/data/data/databases/")
                webSettings.loadsImagesAutomatically = true
                webSettings.cacheMode = WebSettings.LOAD_NO_CACHE
                webSettings.builtInZoomControls = false
                webSettings.domStorageEnabled = true
                webSettings.loadWithOverviewMode = true
                webSettings.useWideViewPort = true
                webSettings.setSupportZoom(true)
                webSettings.layoutAlgorithm = WebSettings.LayoutAlgorithm.SINGLE_COLUMN
                myWebView.scrollBarStyle = WebView.SCROLLBARS_OUTSIDE_OVERLAY
                myWebView.isScrollbarFadingEnabled = true
                myWebView.loadUrl("javascript:dataFromNative('$responseData')")
                val settings: WebSettings = myWebView.settings
                settings.databaseEnabled = true
                settings.domStorageEnabled = true
                val databasePath =
                    this.applicationContext.getDir("web_database", Context.MODE_PRIVATE).path
                settings.setDatabasePath(databasePath)
                myWebView.loadUrl(
                    "${url}/pfm-app?theme=${theme.lowercase()}&api_token=${apiToken}&ref_id=${refId}",
                    tokenHeader
                )

            } catch (y: Exception) {
                y.printStackTrace()
            }
        } catch (e: Exception) {
            e.printStackTrace()
        }
    }


    override fun onSupportNavigateUp(): Boolean {
        onBackPressed()
        return true
    }


    // Overriding WebViewClient functions
    inner class WebViewClient : android.webkit.WebViewClient() {

        // Load the URL
        @Deprecated("Deprecated in Java")
        override fun shouldOverrideUrlLoading(view: WebView, url: String): Boolean {
            view.loadUrl(url)
            return false
        }

        // ProgressBar will disappear once page is loaded
        override fun onPageFinished(view: WebView, url: String) {
            super.onPageFinished(view, url)
            binding.progressBarWebview.visibility = View.GONE
        }
    }

    @Deprecated("Deprecated in Java")
    override fun onBackPressed() {
        val dialogBuilder = AlertDialog.Builder(this)
            .setMessage("Are you sure you want to close?")
            .setPositiveButton(
                "Yes"
            ) { _, _ ->

                Log.d("DATA", "ON dashboard Page")
                finish()
                super.onBackPressed()
            }
            .setNegativeButton("No", null)

        val dialog: AlertDialog = dialogBuilder.create()
        dialog.show()
    }
}
